@@ -24,13 +24,12 @@ import logging
 import os
 import re
 import sys
-from distutils.util import convert_path
 from typing import List, Optional, Tuple
 
 from setuptools import Command
 from setuptools.dist import Distribution
 
-__version__ = (0, 1, 11)
+__version__ = (0, 1, 14)
 DEFAULT_SOURCE_DIR = "po"
 DEFAULT_BUILD_DIR = "locale"
 DEFAULT_LANGUAGE = "en"
@@ -50,6 +49,34 @@ def parse_lang(lang: str) -> List[str]:
     return [i.strip() for i in lang.split(",") if i.strip()]
 
 
+# Imported from distutils.util in Python 3.11:
+def convert_path(pathname):
+    """Return 'pathname' as a name that will work on the native filesystem.
+
+    i.e. split it on '/' and put it back together again using the current
+    directory separator.  Needed because filenames in the setup script are
+    always supplied in Unix style, and have to be converted to the local
+    convention before we can actually use them in the filesystem.  Raises
+    ValueError on non-Unix-ish systems if 'pathname' either starts or
+    ends with a slash.
+    """
+    if os.sep == '/':
+        return pathname
+    if not pathname:
+        return pathname
+    if pathname[0] == '/':
+        raise ValueError(f"path '{pathname}' cannot be absolute")
+    if pathname[-1] == '/':
+        raise ValueError(f"path '{pathname}' cannot end with '/'")
+
+    paths = pathname.split('/')
+    while '.' in paths:
+        paths.remove('.')
+    if not paths:
+        return os.curdir
+    return os.path.join(*paths)
+
+
 class build_mo(Command):
     """Subcommand of build command: build_mo."""
 
@@ -106,16 +133,16 @@ class build_mo(Command):
             return
 
         if find_executable("msgfmt") is None:
-            logging.warn("GNU gettext msgfmt utility not found!")
-            logging.warn("Skip compiling po files.")
+            logging.warning("GNU gettext msgfmt utility not found!")
+            logging.warning("Skip compiling po files.")
             return
 
         default_lang = self.distribution.gettext_default_language
 
         if default_lang in self.lang:
             if find_executable("msginit") is None:
-                logging.warn("GNU gettext msginit utility not found!")
-                logging.warn("Skip creating English PO file.")
+                logging.warning("GNU gettext msginit utility not found!")
+                logging.warning("Skip creating English PO file.")
             else:
                 logging.info("Creating English PO file...")
                 pot = (self.prj_name or "messages") + ".pot"
@@ -386,4 +413,4 @@ def change_root(new_root, pathname):
             path = path[1:]
         return os.path.join(new_root, path)
     else:
-        raise AssertionError("Unsupported OS: %s" % os.name)
+        raise AssertionError(f"Unsupported OS: {os.name}")
